package com.ruoyi.oa.mapper;

import java.util.List;
import com.ruoyi.oa.domain.CmcBorrow;

/**
 * cmc借款申请Mapper接口
 * 
 * @author cmc
 * @date 2024-04-07
 */
public interface CmcBorrowMapper 
{
    /**
     * 查询cmc借款申请
     * 
     * @param borrowId cmc借款申请主键
     * @return cmc借款申请
     */
    public CmcBorrow selectCmcBorrowByBorrowId(String borrowId);

    /**
     * 查询cmc借款申请列表
     * 
     * @param cmcBorrow cmc借款申请
     * @return cmc借款申请集合
     */
    public List<CmcBorrow> selectCmcBorrowList(CmcBorrow cmcBorrow);

    /**
     * 新增cmc借款申请
     * 
     * @param cmcBorrow cmc借款申请
     * @return 结果
     */
    public int insertCmcBorrow(CmcBorrow cmcBorrow);

    /**
     * 修改cmc借款申请
     * 
     * @param cmcBorrow cmc借款申请
     * @return 结果
     */
    public int updateCmcBorrow(CmcBorrow cmcBorrow);

    /**
     * 删除cmc借款申请
     * 
     * @param borrowId cmc借款申请主键
     * @return 结果
     */
    public int deleteCmcBorrowByBorrowId(String borrowId);

    /**
     * 批量删除cmc借款申请
     * 
     * @param borrowIds 需要删除的数据主键集合
     * @return 结果
     */
    public int deleteCmcBorrowByBorrowIds(String[] borrowIds);
}
